diff --git a/installer/c/limewireExe/LimeWire31.rc b/installer/c/i2pExe/I2P.rc
similarity index 72%
rename from installer/c/limewireExe/LimeWire31.rc
rename to installer/c/i2pExe/I2P.rc
index 386d2003b1975d0e56108e5ac1ae2e136d01875b..325d4894318c93b472c5711cc52469f876879cf3 100644
--- a/installer/c/limewireExe/LimeWire31.rc
+++ b/installer/c/i2pExe/I2P.rc
@@ -1,6 +1,6 @@
 // Microsoft Visual C++ generated resource script.
 //
-#include "resource1.h"
+#include "resource.h"
 
 #define APSTUDIO_READONLY_SYMBOLS
 /////////////////////////////////////////////////////////////////////////////
@@ -53,8 +53,8 @@ END
 //
 
 VS_VERSION_INFO VERSIONINFO
- FILEVERSION 1,0,0,2
- PRODUCTVERSION 1,0,0,2
+ FILEVERSION 0,9,5,1
+ PRODUCTVERSION 0,9,5,1
  FILEFLAGSMASK 0x17L
 #ifdef _DEBUG
  FILEFLAGS 0x1L
@@ -69,15 +69,15 @@ BEGIN
     BEGIN
         BLOCK "040904b0"
         BEGIN
-            VALUE "Comments", "The easiest and safest way to get music"
-            VALUE "CompanyName", "The MuWire Project"
-            VALUE "FileDescription", "MuWire"
-            VALUE "FileVersion", "1, 0, 0, 2"
-            VALUE "InternalName", "MuWire"
-            VALUE "LegalCopyright", "GPL"
-            VALUE "OriginalFilename", "MuWire.exe"
-            VALUE "ProductName", " MuWire"
-            VALUE "ProductVersion", "1, 0, 0, 2"
+            VALUE "Comments", "Anonymity for the masses"
+            VALUE "CompanyName", "The I2P Project"
+            VALUE "FileDescription", "I2P"
+            VALUE "FileVersion", "0, 9, 5, 1"
+            VALUE "InternalName", "I2P"
+            VALUE "LegalCopyright", "Public Domain"
+            VALUE "OriginalFilename", "I2P.exe"
+            VALUE "ProductName", " I2P"
+            VALUE "ProductVersion", "0, 9, 5, 1"
         END
     END
     BLOCK "VarFileInfo"
@@ -94,8 +94,7 @@ END
 
 // Icon with lowest ID value placed first to ensure application icon
 // remains consistent on all systems.
-IDI_ICON1               ICON                    "merged icon.ico"
-IDI_ICON2               ICON                    "torrent.ico"
+IDI_ICON1               ICON                    "start.ico"
 #endif    // English (U.S.) resources
 /////////////////////////////////////////////////////////////////////////////
 
diff --git a/installer/c/limewireExe/LimeWire3.sln b/installer/c/i2pExe/I2P.sln
similarity index 88%
rename from installer/c/limewireExe/LimeWire3.sln
rename to installer/c/i2pExe/I2P.sln
index 789dc66e4f1d2df61399f3bf675be8bfd0d86a31..eabda8a1f764e03c30512bd08cdfe043c7951aee 100644
--- a/installer/c/limewireExe/LimeWire3.sln
+++ b/installer/c/i2pExe/I2P.sln
@@ -1,6 +1,6 @@
 Microsoft Visual Studio Solution File, Format Version 10.00
 # Visual Studio 2008
-Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "LimeWire3", "LimeWire3.vcproj", "{0A74F3D1-C70A-4CF0-9390-C676025ED12F}"
+Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "I2P", "I2P.vcproj", "{0A74F3D1-C70A-4CF0-9390-C676025ED12F}"
 EndProject
 Global
 	GlobalSection(SolutionConfigurationPlatforms) = preSolution
diff --git a/installer/c/i2pExe/I2P.suo b/installer/c/i2pExe/I2P.suo
new file mode 100644
index 0000000000000000000000000000000000000000..0eb2da43b07ed18b4727a9baa037e0a88a1f1c03
Binary files /dev/null and b/installer/c/i2pExe/I2P.suo differ
diff --git a/installer/c/limewireExe/LimeWire3.vcproj b/installer/c/i2pExe/I2P.vcproj
similarity index 89%
rename from installer/c/limewireExe/LimeWire3.vcproj
rename to installer/c/i2pExe/I2P.vcproj
index e66c9e10ceeb42374dc6d76d200f6f9049c30e72..ff3f3a9f8d354517969e726f9f6b87cbc447c91a 100644
--- a/installer/c/limewireExe/LimeWire3.vcproj
+++ b/installer/c/i2pExe/I2P.vcproj
@@ -2,9 +2,9 @@
 <VisualStudioProject
 	ProjectType="Visual C++"
 	Version="9.00"
-	Name="LimeWire3"
+	Name="I2P"
 	ProjectGUID="{0A74F3D1-C70A-4CF0-9390-C676025ED12F}"
-	RootNamespace="LimeWire3"
+	RootNamespace="I2P"
 	Keyword="Win32Proj"
 	TargetFrameworkVersion="131072"
 	>
@@ -64,10 +64,10 @@
 			<Tool
 				Name="VCLinkerTool"
 				AdditionalDependencies="Shlwapi.lib"
-				OutputFile="$(OutDir)/LimeWire.exe"
+				OutputFile="$(OutDir)/I2P.exe"
 				LinkIncremental="2"
 				GenerateDebugInformation="true"
-				ProgramDatabaseFile="$(OutDir)/LimeWire3.pdb"
+				ProgramDatabaseFile="$(OutDir)/I2P.pdb"
 				SubSystem="2"
 				RandomizedBaseAddress="1"
 				DataExecutionPrevention="0"
@@ -78,7 +78,7 @@
 			/>
 			<Tool
 				Name="VCManifestTool"
-				AdditionalManifestFiles="LimeWire.exe.manifest"
+				AdditionalManifestFiles="I2P.exe.manifest"
 			/>
 			<Tool
 				Name="VCXDCMakeTool"
@@ -143,7 +143,7 @@
 			<Tool
 				Name="VCLinkerTool"
 				AdditionalDependencies="shlwapi.lib"
-				OutputFile="$(OutDir)/MuWire.exe"
+				OutputFile="$(OutDir)/I2P.exe"
 				LinkIncremental="1"
 				GenerateDebugInformation="true"
 				SubSystem="2"
@@ -223,7 +223,7 @@
 			<Tool
 				Name="VCLinkerTool"
 				AdditionalDependencies="shlwapi.lib"
-				OutputFile="$(OutDir)/LimeWire.exe"
+				OutputFile="$(OutDir)/I2P.exe"
 				LinkIncremental="1"
 				GenerateDebugInformation="true"
 				SubSystem="2"
@@ -265,15 +265,15 @@
 			UniqueIdentifier="{4FC737F1-C7A5-4376-A066-2A32D752A2FF}"
 			>
 			<File
-				RelativePath=".\java.c"
+				RelativePath=".\i2p.c"
 				>
 			</File>
 			<File
-				RelativePath=".\java_md.c"
+				RelativePath=".\java.c"
 				>
 			</File>
 			<File
-				RelativePath=".\limewire.c"
+				RelativePath=".\java_md.c"
 				>
 			</File>
 		</Filter>
@@ -303,7 +303,7 @@
 				>
 			</File>
 			<File
-				RelativePath=".\resource1.h"
+				RelativePath=".\resource.h"
 				>
 			</File>
 		</Filter>
@@ -313,15 +313,11 @@
 			UniqueIdentifier="{67DA6AB6-F800-4c08-8B7A-83BB121AAD01}"
 			>
 			<File
-				RelativePath=".\LimeWire31.rc"
-				>
-			</File>
-			<File
-				RelativePath=".\merged icon.ico"
+				RelativePath=".\I2P.rc"
 				>
 			</File>
 			<File
-				RelativePath=".\torrent.ico"
+				RelativePath="..\..\resources\start.ico"
 				>
 			</File>
 		</Filter>
diff --git a/installer/c/limewireExe/errors.h b/installer/c/i2pExe/errors.h
similarity index 71%
rename from installer/c/limewireExe/errors.h
rename to installer/c/i2pExe/errors.h
index 6802181d2aaafd9c3c40277e997b9a8a81dde99c..d8c744c68ff412ca33ed4587f6d1928bc86d18bf 100644
--- a/installer/c/limewireExe/errors.h
+++ b/installer/c/i2pExe/errors.h
@@ -1,5 +1,5 @@
-#ifndef _LIME_ERRORS_H
-#define _LIME_ERRORS_h
+#ifndef _I2P_ERRORS_H
+#define _I2P_ERRORS_h
 
 
 #define ERROR_COULDNT_LOAD_JVM 6
@@ -8,4 +8,4 @@
 #define ERROR_STARTING_PROGRAM 9
 #define ERROR_COULDNT_FIND_JVM 10
 
-#endif /* _LIME_ERRORS_H */
\ No newline at end of file
+#endif /* _I2P_ERRORS_H */
\ No newline at end of file
diff --git a/installer/c/limewireExe/java.c b/installer/c/i2pExe/java.c
similarity index 100%
rename from installer/c/limewireExe/java.c
rename to installer/c/i2pExe/java.c
diff --git a/installer/c/limewireExe/java.h b/installer/c/i2pExe/java.h
similarity index 100%
rename from installer/c/limewireExe/java.h
rename to installer/c/i2pExe/java.h
diff --git a/installer/c/limewireExe/java_md.c b/installer/c/i2pExe/java_md.c
similarity index 100%
rename from installer/c/limewireExe/java_md.c
rename to installer/c/i2pExe/java_md.c
diff --git a/installer/c/limewireExe/java_md.h b/installer/c/i2pExe/java_md.h
similarity index 100%
rename from installer/c/limewireExe/java_md.h
rename to installer/c/i2pExe/java_md.h
diff --git a/installer/c/limewireExe/jni.h b/installer/c/i2pExe/jni.h
similarity index 100%
rename from installer/c/limewireExe/jni.h
rename to installer/c/i2pExe/jni.h
diff --git a/installer/c/limewireExe/jni_md.h b/installer/c/i2pExe/jni_md.h
similarity index 100%
rename from installer/c/limewireExe/jni_md.h
rename to installer/c/i2pExe/jni_md.h
diff --git a/installer/c/limewireExe/resource1.h b/installer/c/i2pExe/resource.h
similarity index 82%
rename from installer/c/limewireExe/resource1.h
rename to installer/c/i2pExe/resource.h
index cd8ba7818e40e067ae1e1423bf6447d755b192ea..1489e81f2be02be8868d78d3f7292d6cbcb0b857 100644
--- a/installer/c/limewireExe/resource1.h
+++ b/installer/c/i2pExe/resource.h
@@ -1,9 +1,8 @@
 //{{NO_DEPENDENCIES}}
 // Microsoft Visual C++ generated include file.
-// Used by LimeWire31.rc
+// Used by I2P.rc
 //
 #define IDI_ICON1                       111
-#define IDI_ICON2                       112
 
 // Next default values for new objects
 // 
diff --git a/installer/c/limewireExe/limewire.c b/installer/c/i2pExe/i2p.c
similarity index 87%
rename from installer/c/limewireExe/limewire.c
rename to installer/c/i2pExe/i2p.c
index 876e49fa3f8dae561425c1d2a4c9712ebdf077a6..ee7a2d74cd1f91b5d61e97f0632a30a8f9199982 100644
--- a/installer/c/limewireExe/limewire.c
+++ b/installer/c/i2pExe/i2p.c
@@ -1,8 +1,8 @@
 /** 
- * Customized LimeWire launcher.
+ * Customized I2P launcher.
  * Launches the JRE within the process, to allow Task Manager to show
  * "LimeWire.exe" as the process, and firewalls to control access of
  * "LimeWire.exe".
  */
 
 #include "errors.h"
@@ -53,7 +53,7 @@ main(int argc, char** argv) {
 	for(i = 1; i <= read_options_size; i++)
 		new_argv[i] = read_options[i-1];
 	// copy argv arguments as arguments after the properties file
-	// (generally used as arguments for LimeWire)
+	// (generally used as arguments for I2P)
 	for(current_argc = 1; current_argc < argc; current_argc++)
 		new_argv[i++] = argv[current_argc];
 
@@ -69,20 +69,20 @@ main(int argc, char** argv) {
 	case ERROR_COULDNT_FIND_JVM:
 	case ERROR_COULDNT_INITIALIZE_JVM:
 	case ERROR_COULDNT_LOAD_JVM:
-		if (MessageBox(NULL, "MuWire needs the Java Runtime Environment 6.0 or above. Click OK to go to www.java.com, where you can install Java.", 
-		       "MuWire Launcher Error",
+		if (MessageBox(NULL, "I2P needs the Java Runtime Environment 5.0 or above. Click OK to go to www.java.com, where you can install Java.", 
+		       "I2P Launcher Error",
 		       MB_ICONWARNING | MB_OKCANCEL) == IDOK)
 			ShellExecute(NULL, NULL, "http://www.java.com/", "", "", SW_SHOWNORMAL);
 		break;
 	case ERROR_COULDNT_PARSE_ARGUMENTS:
-		MessageBox(NULL, "MuWire failed to parse the commandline arguments to Java.\n"
-			"Please download and install MuWire again.",
-			"MuWire Launcher Error", MB_OK);
+		MessageBox(NULL, "I2P failed to parse the commandline arguments to Java.\n"
+			"Please download and install I2P again.",
+			"I2P Launcher Error", MB_OK);
 		break;
 	case ERROR_STARTING_PROGRAM:
-		MessageBox(NULL, "MuWire was unable to load.\n"
-				"Please download and install MuWire again.",
-				"MuWire Launcher Error", MB_OK);
+		MessageBox(NULL, "I2P was unable to load.\n"
+				"Please download and install I2P again.",
+				"I2P Launcher Error", MB_OK);
 		break;
 	}
 	return ret;
@@ -128,7 +128,7 @@ void readOptions(char*** options, int* size) {
 #pragma message ("\n\n!!!!!!!!!!!!!! building ALPHA !!!!!!!!!!!!!!\n\n")
 		(*options)[(*size) - 3] = "-agentlib:yjpagent=port=11111";
 		(*options)[(*size) - 2] = "-jar";
-		(*options)[(*size) - 1] = "LimeWire.jar";
+		(*options)[(*size) - 1] = "I2P.jar";
 #endif
 		return;
 	}
@@ -165,7 +165,7 @@ void readOptions(char*** options, int* size) {
 }
 
 /*
  * Sets the current working directory to wherever LimeWire.exe is located
  */
 static void
 SetWorkingDirectory(char *path) {
@@ -231,4 +231,4 @@ WinMain(HINSTANCE inst, HINSTANCE previnst, LPSTR cmdline, int cmdshow)
     ret = main(__argc, __argv);
 
     return ret; 
-}
\ No newline at end of file
+}
@@ -1,8 +1,8 @@
  * Launches the JRE within the process, to allow Task Manager to show
- * "LimeWire.exe" as the process, and firewalls to control access of
- * "LimeWire.exe".
+ * "I2P.exe" as the process, and firewalls to control access of
+ * "I2P.exe".
  */
 
@@ -165,7 +165,7 @@ void readOptions(char*** options, int* size) {
 
 /*
- * Sets the current working directory to wherever LimeWire.exe is located
+ * Sets the current working directory to wherever I2P.exe is located
  */
 static void
diff --git a/installer/c/limewireExe/LimeWire3.suo b/installer/c/limewireExe/LimeWire3.suo
deleted file mode 100644
index 0cdc68d24bac7fb30382adb642e7b21b926ab5c3..0000000000000000000000000000000000000000
Binary files a/installer/c/limewireExe/LimeWire3.suo and /dev/null differ
diff --git a/installer/c/limewireExe/merged icon.ico b/installer/c/limewireExe/merged icon.ico
deleted file mode 100644
index d43cef886eb91d286c0208e0d84baa3bd7b41f4d..0000000000000000000000000000000000000000
Binary files a/installer/c/limewireExe/merged icon.ico and /dev/null differ
diff --git a/installer/c/limewireExe/torrent.ico b/installer/c/limewireExe/torrent.ico
deleted file mode 100644
index 3a4da56a01182ff29a808612d1549fbbbb86975e..0000000000000000000000000000000000000000
Binary files a/installer/c/limewireExe/torrent.ico and /dev/null differ